CMIP6 source_id values
Author: Paul J. Durack
Description: Controlled vocabulary for CMIP6
Keywords: HTML, CSS, JavaScript

# WCRP-CMIP CMIP6_CVs version: 6.2.60.0

#### Experiment IDs | Institution IDs | Source IDs | Source IDs (incl licenses) | Citations by (Source ID, Institution Id, Activity ID) | Citations by (Source ID, Institution Id, Activity ID, Experiment ID) |

source_id | institution id | release year | activity participation | cohort | label | label extended | atmos | natNomRes atmos | ocean | natNomRes ocean | landIce | natNomRes landIce | aerosol | atmosChem | land | ocnBgchem | seaIce
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
source_id | institution id | release year | activity participation | cohort | label | label extended | atmos | natNomRes atmos | ocean | natNomRes ocean | landIce | natNomRes landIce | aerosol | atmosChem | land | ocnBgchem | seaIce
4AOP-v1-5 | IPSL | 2019 | RFMIP | Published | 4AOP-v1-5 | Line-By-Line Radiative Transfer Model v1.5, Laboratoire Meteorologie Dynamique, GEISA spectroscopic database | none | none | none | none | none | none | none | none | none | none | none
ACCESS-CM2 | CSIRO-ARCCSS | 2019 | CMIP DAMIP FAFMIP OMIP RFMIP SIMIP ScenarioMIP | Published | ACCESS-CM2 | Australian Community Climate and Earth System Simulator Climate Model Version 2 | MetUM-HadGEM3-GA7.1 (N96; 192 x 144 longitude/latitude; 85 levels; top level 85 km) | 250 km | ACCESS-OM2 (GFDL-MOM5, tripolar primarily 1deg; 360 x 300 longitude/latitude; 50 levels; top grid cell 0-10 m) | 100 km | none | none | UKCA-GLOMAP-mode | none | CABLE2.5 | none | CICE5.1.2 (same grid as ocean)
ACCESS-ESM1-5 | CSIRO | 2019 | C4MIP CDRMIP CMIP DAMIP LUMIP OMIP PMIP RFMIP ScenarioMIP | Published | ACCESS-ESM1.5 | Australian Community Climate and Earth System Simulator Earth System Model Version 1.5 | HadGAM2 (r1.1, N96; 192 x 145 longitude/latitude; 38 levels; top level 39255 m) | 250 km | ACCESS-OM2 (MOM5, tripolar primarily 1deg; 360 x 300 longitude/latitude; 50 levels; top grid cell 0-10 m) | 100 km | none | none | CLASSIC (v1.0) | none | CABLE2.4 | WOMBAT (same grid as ocean) | CICE4.1 (same grid as ocean)
ACCESS-OM2 | CSIRO-COSIMA | 2020 | OMIP | Published | ACCESS-OM2 | Australian Community Climate and Earth System Simulator Ocean Model Version 2 | none | none | ACCESS-OM2 (MOM5, tripolar primarily 1deg; 360 x 300 longitude/latitude; 50 levels; top grid cell 0-2.3 m) | 100 km | none | none | none | none | none | WOMBAT (same grid as ocean) | CICE5.1.2 (same grid as ocean)
ACCESS-OM2-025 | CSIRO-COSIMA | 2020 | OMIP | Published | ACCESS-OM2-025 | Australian Community Climate and Earth System Simulator Ocean Model Version 2 quarter degree | none | none | ACCESS-OM2 (MOM5, tripolar primarily 1/4 deg; 1440 x 1080 longitude/latitude; 50 levels; top grid cell 0-2.3 m) | 25 km | none | none | none | none | none | WOMBAT (same grid as ocean) | CICE5.1.2 (same grid as ocean)
ARTS-2-3 | UHH | 2015 | RFMIP | Published | ARTS 2.3 | ARTS 2.3 (Current development version of the Atmospheric Radiative Transfer Simulator) | none | none | none | none | none | none | none | none | none | none | none
AWI-CM-1-1-HR | AWI | 2018 | CMIP CORDEX HighResMIP OMIP SIMIP VIACSAB | Published | AWI-CM 1.1 HR | AWI-CM 1.1 HR | ECHAM6.3.04p1 (T127L95 native atmosphere T127 gaussian grid; 384 x 192 longitude/latitude; 95 levels; top level 80 km) | 100 km | FESOM 1.4 (unstructured grid in the horizontal with 1306775 wet nodes; 46 levels; top grid cell 0-5 m) | 25 km | none | none | none | none | JSBACH 3.20 | none | FESOM 1.4
AWI-CM-1-1-LR | AWI | 2018 | CMIP CORDEX HighResMIP OMIP SIMIP ScenarioMIP VIACSAB | Published | AWI-CM 1.1 LR | AWI-CM 1.1 LR | ECHAM6.3.04p1 (T63L47 native atmosphere T63 gaussian grid; 192 x 96 longitude/latitude; 47 levels; top level 80 km) | 250 km | FESOM 1.4 (unstructured grid in the horizontal with 126859 wet nodes; 46 levels; top grid cell 0-5 m) | 100 km | none | none | none | none | JSBACH 3.20 | none | FESOM 1.4
AWI-CM-1-1-MR | AWI | 2018 | CMIP CORDEX OMIP PAMIP SIMIP ScenarioMIP VIACSAB | Published | AWI-CM 1.1 MR | AWI-CM 1.1 MR | ECHAM6.3.04p1 (T127L95 native atmosphere T127 gaussian grid; 384 x 192 longitude/latitude; 95 levels; top level 80 km) | 100 km | FESOM 1.4 (unstructured grid in the horizontal with 830305 wet nodes; 46 levels; top grid cell 0-5 m) | 25 km | none | none | none | none | JSBACH 3.20 | none | FESOM 1.4
AWI-ESM-1-1-LR | AWI | 2018 | CMIP PMIP | Published | AWI-ESM 1.1 LR | AWI-ESM 1.1 LR | ECHAM6.3.04p1 (T63L47 native atmosphere T63 gaussian grid; 192 x 96 longitude/latitude; 47 levels; top level 80 km) | 250 km | FESOM 1.4 (unstructured grid in the horizontal with 126859 wet nodes; 46 levels; top grid cell 0-5 m) | 100 km | none | none | none | none | JSBACH 3.20 with dynamic vegetation | none | FESOM 1.4
AWI-ESM-1-REcoM | AWI | 2024 | C4MIP CDRMIP CMIP ScenarioMIP | Published | AWI-ESM 1 REcoM | AWI-ESM 1 REcoM | ECHAM6.3.04p1 (T63L47 native atmosphere T63 gaussian grid; 192 x 96 longitude/latitude; 47 levels; top level 80 km) | 250 km | FESOM 1.4 (unstructured grid in the horizontal with 126859 wet nodes; 46 levels; top grid cell 0-5 m) | 100 km | none | none | none | none | JSBACH 3.20 with dynamic vegetation | REcoM2 (same grid as ocean component) | FESOM 1.4 (same grid as ocean component)
BCC-CSM2-HR | BCC | 2017 | CMIP HighResMIP | Published | BCC-CSM 2 HR | BCC-CSM 2 HR | BCC_AGCM3_HR (T266; 800 x 400 longitude/latitude; 56 levels; top level 0.1 hPa) | 50 km | MOM4 (1/3 deg 10S-10N, 1/3-1 deg 10-30 N/S, and 1 deg in high latitudes; 360 x 232 longitude/latitude; 40 levels; top grid cell 0-10 m) | 50 km | none | none | none | none | BCC_AVIM2 | none | SIS2
BCC-CSM2-MR | BCC | 2017 | C4MIP CFMIP CMIP DAMIP DCPP GMMIP LS3MIP LUMIP RFMIP ScenarioMIP | Published | BCC-CSM 2 MR | BCC-CSM 2 MR | BCC_AGCM3_MR (T106; 320 x 160 longitude/latitude; 46 levels; top level 1.46 hPa) | 100 km | MOM4 (1/3 deg 10S-10N, 1/3-1 deg 10-30 N/S, and 1 deg in high latitudes; 360 x 232 longitude/latitude; 40 levels; top grid cell 0-10 m) | 50 km | none | none | none | none | BCC_AVIM2 | none | SIS2
BCC-ESM1 | BCC | 2017 | AerChemMIP CMIP | Published | BCC-ESM 1 | BCC-ESM 1 | BCC_AGCM3_LR (T42; 128 x 64 longitude/latitude; 26 levels; top level 2.19 hPa) | 250 km | MOM4 (1/3 deg 10S-10N, 1/3-1 deg 10-30 N/S, and 1 deg in high latitudes; 360 x 232 longitude/latitude; 40 levels; top grid cell 0-10 m) | 50 km | none | none | none | BCC-AGCM3-Chem | BCC_AVIM2 | none | SIS2
CAM-MPAS-HR | PNNL-WACCEM | 2018 | HighResMIP | Published | CAM-MPAS-HR | CAM MPAS (Community Atmosphere Model - Model for Prediction Across Scales) | CAM-MPAS (CAMv5.4 with Grell-Freitas deep convection; MPASv4, C-grid staggered centroidal Voronoi tesselation atmosphere 30 km mesh with 655362 cells and 1966080 edges; 32 levels, top level 40363 m) | 25 km | none | none | none | none | none, prescribed MACv2-SP | none | CLM (v4.0, same grid as atmos), River Transport Model (v1.0) | none | none
CAM-MPAS-LR | PNNL-WACCEM | 2018 | HighResMIP | Published | CAM-MPAS-LR | CAM MPAS (Community Atmosphere Model - Model for Prediction Across Scales) | CAM-MPAS (CAMv5.4 with Grell-Freitas deep convection; MPASv4, C-grid staggered centroidal Voronoi tesselation atmosphere 120 km mesh with 40962 cells and 122880 edges; 32 vertical levels, model top 40363 m) | 100 km | none | none | none | none | none, prescribed MACv2-SP | none | CLM (v4.0, same grid as atmos), River Transport Model (v1.0) | none | none
CAMS-CSM1-0 | CAMS | 2016 | CFMIP CMIP GMMIP HighResMIP ScenarioMIP | Published | CAMS-CSM 1.0 | CAMS-CSM 1.0 | ECHAM5_CAMS (T106; 320 x 160 longitude/latitude; 31 levels; top level 10 mb) | 100 km | MOM4 (tripolar; 360 x 200 longitude/latitude, primarily 1deg latitude/longitude, down to 1/3deg within 30deg of the equatorial tropics; 50 levels; top grid cell 0-10 m) | 100 km | none | none | none | none | CoLM 1.0 | none | SIS 1.0
CAS-ESM2-0 | CAS | 2019 | AerChemMIP C4MIP CDRMIP CFMIP CMIP CORDEX DAMIP DynVarMIP FAFMIP GMMIP GeoMIP HighResMIP LS3MIP LUMIP OMIP PMIP SIMIP ScenarioMIP VIACSAB VolMIP | Published | CAS-ESM 2.0 | CAS-ESM 2.0 (Chinese Academy of Sciences Earth System Model version 2.0) | IAP AGCM 5.0 (Finite difference dynamical core; 256 x 128 longitude/latitude; 35 levels; top level 2.2 hPa) | 100 km | LICOM2.0 (LICOM2.0, primarily 1deg; 362 x 196 longitude/latitude; 30 levels; top grid cell 0-10 m) | 100 km | none | none | IAP AACM | IAP AACM | CoLM | IAP OBGCM | CICE4
CESM1-1-CAM5-CMIP5 | NCAR | 2011 | CMIP DCPP | Published | CESM1-1-CAM5-CMIP5 | CESM1-1-CAM5-CMIP5 | CAM5.2 (0.9x1.25 finite volume grid; 288 x 192 longitude/latitude; 32 levels; top level 2.25 mb) | 100 km | POP2 (320x384 longitude/latitude; 60 levels; top grid cell 0-10 m) | 100 km | none | none | MAM3 (same grid as atmos) | MAM3 (same grid as atmos) | CLM4 (same grid as atmos) | BEC (same grid as ocean) | CICE4 (same grid as ocean)
CESM1-CAM5-SE-HR | NCAR | 2012 | HighResMIP | Published | CESM1-CAM5-SE-HR | CESM 1.3 CAM5 spectral element configuration with CMIP5 forcings, hi res | CAM5.2 (0.25 degree spectral element; 777602 cells; 30 levels; top level 2.25 mb) | 25 km | POP2 (3600x2400 longitude/latitude; 62 levels; top grid cell 0-10 m) | 10 km | none | none | MAM3 (same grid as atmos) | MAM3 (same grid as atmos) | CLM4 (same grid as atmos) | "BEC (same grid as ocean) | CICE4 (same grid as ocean)
CESM1-CAM5-SE-LR | NCAR | 2012 | HighResMIP | Published | CESM1-CAM5-SE-LR | CESM 1.3 CAM5 spectral element configuration with CMIP5 forcings, lo res | CAM5.2 (1 degree spectral element; 48602 cells; 30 levels; top level 2.25 mb) | 100 km | POP2 (320x384 longitude/latitude; 60 levels; top grid cell 0-10 m) | 100 km | none | none | MAM3 (same grid as atmos) | MAM3 (same grid as atmos) | CLM4 (same grid as atmos) | "BEC (same grid as ocean) | CICE4 (same grid as ocean)
CESM1-WACCM-SC | UCI NCAR | 2011 | PAMIP | Published | CESM1-WACCM-SC | Community Earth System Model 1, with the Whole Atmosphere Community Climate Model and Specified Chemistry | WACCM4 (1.9x2.5 finite volume grid; 144 x 96 longitude/latitude; 66 levels; top level 5.9e-06 mb) | 250 km | POP2 (320 x 384 longitude/latitude; 60 levels; top grid cell 0-10 m) | 100 km | none | none | MOZART-specified (same grid as atmos) | MOZART-specified (same grid as atmos) | CLM4.0 | BEC (same grid as ocean) | CICE4 (same as grid as ocean)
CESM2 | NCAR | 2018 | AerChemMIP C4MIP CDRMIP CFMIP CMIP CORDEX DAMIP DCPP DynVarMIP FAFMIP GMMIP GeoMIP HighResMIP ISMIP6 LS3MIP LUMIP OMIP PAMIP PMIP RFMIP RFMIP SIMIP ScenarioMIP VIACSAB VolMIP | Published | CESM2 | CESM2 | CAM6 (0.9x1.25 finite volume grid; 288 x 192 longitude/latitude; 32 levels; top level 2.25 mb) | 100 km | POP2 (320x384 longitude/latitude; 60 levels; top grid cell 0-10 m) | 100 km | CISM2.1 | 5 km | MAM4 (same grid as atmos) | MAM4 (same grid as atmos) | CLM5 (same grid as atmos) | MARBL (same grid as ocean) | CICE5.1 (same grid as ocean)
CESM2-FV2 | NCAR | 2019 | CMIP PMIP ScenarioMIP | Published | CESM2-FV2 | CESM2-FV2 | CAM6 (1.9x2.5 finite volume grid; 144 x 96 longitude/latitude; 32 levels; top level 2.25 mb) | 250 km | POP2 (320x384 longitude/latitude; 60 levels; top grid cell 0-10 m) | 100 km | CISM2.1 | 5 km | MAM4 (same grid as atmos) | MAM4 (same grid as atmos) | CLM5 (same grid as atmos) | MARBL (same grid as ocean) | CICE5.1 (same grid as ocean)
CESM2-WACCM | NCAR | 2018 | AerChemMIP CMIP GeoMIP RFMIP ScenarioMIP | Published | CESM2-WACCM | CESM2-WACCM | WACCM6 (0.9x1.25 finite volume grid; 288 x 192 longitude/latitude; 70 levels; top level 4.5e-06 mb) | 100 km | POP2 (320 x 384 longitude/latitude; 60 levels; top grid cell 0-10 m) | 100 km | CISM2.1 | 5 km | MAM4 (same grid as atmos) | MAM4 (same grid as atmos) | CLM5 (same grid as atmos) | MARBL (same grid as ocean) | CICE5.1 (same grid as ocean)
CESM2-WACCM-FV2 | NCAR | 2019 | CMIP PMIP | Published | CESM2-WACCM-FV2 | CESM2-WACCM-FV2 | WACCM6 (1.9x2.5 finite volume grid; 144 x 96 longitude/latitude; 70 levels; top level 4.5e-06 mb) | 250 km | POP2 (320x384 longitude/latitude; 60 levels; top grid cell 0-10 m) | 100 km | CISM2.1 | 5 km | MAM4 (same grid as atmos) | MAM4 (same grid as atmos) | CLM5 (same grid as atmos) | MARBL (same grid as ocean) | CICE5.1 (same grid as ocean)
CIESM | THU | 2017 | CFMIP CMIP CORDEX GMMIP HighResMIP OMIP SIMIP ScenarioMIP | Published | CIESM | Community Integrated Earth System Model | CIESM-AM (FV/FD; 288 x 192 longitude/latitude; 30 levels; top level 2.255 hPa) | 100 km | CIESM-OM (FD, SCCGrid Displaced Pole; 720 x 560 longitude/latitude; 46 levels; top grid cell 0-6 m) | 50 km | none | none | MAM4 | trop_mam4 | CIESM-LM (modified CLM4.5) | none | CICE4
CMCC-CM2-HR4 | CMCC | 2016 | CMIP HighResMIP OMIP | Published | CMCC-CM2-HR4 | CMCC-CM2-HR4 | CAM4 (1deg; 288 x 192 longitude/latitude; 26 levels; top at ~2 hPa) | 100 km | NEMO3.6 (ORCA0.25 1/4 deg from the Equator degrading at the poles; 1442 x 1051 longitude/latitude; 50 vertical levels; top grid cell 0-1 m) | 25 km | none | none | prescribed MACv2-SP | none | CLM4.5 (SP mode) | none | CICE4.0
CMCC-CM2-SR5 | CMCC | 2016 | AerChemMIP CMIP DAMIP DCPP GMMIP OMIP ScenarioMIP | Published | CMCC-CM2-SR5 | CMCC-CM2-SR5 | CAM5.3 (1deg; 288 x 192 longitude/latitude; 30 levels; top at ~2 hPa) | 100 km | NEMO3.6 (ORCA1 tripolar primarly 1 deg lat/lon with meridional refinement down to 1/3 degree in the tropics; 362 x 292 longitude/latitude; 50 vertical levels; top grid cell 0-1 m) | 100 km | none | none | MAM3 | none | CLM4.5 (BGC mode) | none | CICE4.0
CMCC-CM2-VHR4 | CMCC | 2017 | CMIP HighResMIP | Published | CMCC-CM2-VHR4 | CMCC-CM2-VHR4 | CAM4 (1/4deg; 1152 x 768 longitude/latitude; 26 levels; top at ~2 hPa) | 25 km | NEMO3.6 (ORCA0.25 1/4 deg from the Equator degrading at the poles; 1442 x 1051 longitude/latitude; 50 vertical levels; top grid cell 0-1 m) | 25 km | none | none | prescribed MACv2-SP | none | CLM4.5 (SP mode) | none | CICE4.0
CMCC-ESM2 | CMCC | 2017 | C4MIP CMIP LS3MIP LUMIP OMIP ScenarioMIP | Published | CMCC-ESM2 | CMCC-ESM2 | CAM5.3 (1deg; 288 x 192 longitude/latitude; 30 levels; top at ~2 hPa) | 100 km | NEMO3.6 (ORCA1 tripolar primarly 1 deg lat/lon with meridional refinement down to 1/3 degree in the tropics; 362 x 292 longitude/latitude; 50 vertical levels; top grid cell 0-1 m) | 100 km | none | none | MAM3 | none | CLM4.5 (BGC mode) | BFM5.2 | CICE4.0
CNRM-CM6-1 | CNRM-CERFACS | 2017 | CFMIP CMIP DAMIP DCPP FAFMIP GMMIP HighResMIP ISMIP6 LS3MIP OMIP PAMIP PMIP RFMIP ScenarioMIP | Published | CNRM-CM6-1 | CNRM-CM6-1 | Arpege 6.3 (T127; Gaussian Reduced with 24572 grid points in total distributed over 128 latitude circles (with 256 grid points per latitude circle between 30degN and 30degS reducing to 20 grid points per latitude circle at 88.9degN and 88.9degS); 91 levels; top level 78.4 km) | 250 km | Nemo 3.6 (eORCA1, tripolar primarily 1deg; 362 x 294 longitude/latitude; 75 levels; top grid cell 0-1 m) | 100 km | none | none | prescribed monthly fields computed by TACTIC_v2 scheme | OZL_v2 | Surfex 8.0c | none | Gelato 6.1
CNRM-CM6-1-HR | CNRM-CERFACS | 2017 | CMIP DCPP GMMIP HighResMIP OMIP ScenarioMIP | Published | CNRM-CM6-1-HR | CNRM-CM6-1-HR | Arpege 6.3 (T359; Gaussian Reduced with 181724 grid points in total distributed over 360 latitude circles (with 720 grid points per latitude circle between 32.2degN and 32.2degS reducing to 18 grid points per latitude circle at 89.6degN and 89.6degS); 91 levels; top level 78.4 km) | 100 km | Nemo 3.6 (eORCA025, tripolar primarily 1/4deg; 1442 x 1050 longitude/latitude; 75 levels; top grid cell 0-1 m) | 25 km | none | none | prescribed monthly fields computed by TACTIC_v2 scheme | OZL_v2 | Surfex 8.0c | none | Gelato 6.1
CNRM-ESM2-1 | CNRM-CERFACS | 2017 | AerChemMIP C4MIP CDRMIP CMIP CORDEX DCPP GMMIP GeoMIP LS3MIP LUMIP OMIP RFMIP ScenarioMIP | Published | CNRM-ESM2-1 | CNRM-ESM2-1 | Arpege 6.3 (T127; Gaussian Reduced with 24572 grid points in total distributed over 128 latitude circles (with 256 grid points per latitude circle between 30degN and 30degS reducing to 20 grid points per latitude circle at 88.9degN and 88.9degS); 91 levels; top level 78.4 km) | 250 km | Nemo 3.6 (eORCA1, tripolar primarily 1deg; 362 x 294 longitude/latitude; 75 levels; top grid cell 0-1 m) | 100 km | none | none | TACTIC_v2 | REPROBUS-C_v2 | Surfex 8.0c | Pisces 2.s | Gelato 6.1
CanESM5 | CCCma | 2019 | C4MIP CDRMIP CFMIP CMIP CORDEX DAMIP DCPP DynVarMIP FAFMIP GMMIP GeoMIP ISMIP6 LS3MIP LUMIP OMIP PAMIP RFMIP SIMIP ScenarioMIP VIACSAB VolMIP | Published | CanESM5 | CanESM5 | CanAM5 (T63L49 native atmosphere, T63 Linear Gaussian Grid; 128 x 64 longitude/latitude; 49 levels; top level 1 hPa) | 500 km | NEMO3.4.1 (ORCA1 tripolar grid, 1 deg with refinement to 1/3 deg within 20 degrees of the equator; 361 x 290 longitude/latitude; 45 vertical levels; top grid cell 0-6.19 m) | 100 km | specified ice sheets | 500 km | interactive | specified oxidants for aerosols | CLASS3.6/CTEM1.2 | Canadian Model of Ocean Carbon (CMOC); NPZD ecosystem with OMIP prescribed carbonate chemistry | LIM2
CanESM5-1 | CCCma | 2022 | C4MIP CDRMIP CFMIP CMIP CORDEX DAMIP DCPP DynVarMIP FAFMIP GMMIP GeoMIP ISMIP6 LS3MIP LUMIP OMIP PAMIP RFMIP SIMIP ScenarioMIP VIACSAB VolMIP | Published | CanESM5.1 | CanESM5.1 | CanAM5.1 (T63L49 native atmosphere, T63 Linear Gaussian Grid; 128 x 64 longitude/latitude; 49 levels; top level 1 hPa) | 500 km | NEMO3.4.1 (ORCA1 tripolar grid, 1 deg with refinement to 1/3 deg within 20 degrees of the equator; 361 x 290 longitude/latitude; 45 vertical levels; top grid cell 0-6.19 m) | 100 km | specified ice sheets | 500 km | interactive | specified oxidants for aerosols | CLASS3.6/CTEM1.2 | Canadian Model of Ocean Carbon (CMOC); NPZD ecosystem with OMIP prescribed carbonate chemistry | LIM2
CanESM5-CanOE | CCCma | 2019 | C4MIP CDRMIP CMIP OMIP ScenarioMIP | Published | CanESM5-CanOE | CanESM5-CanOE | CanAM5 (T63L49 native atmosphere, T63 Linear Gaussian Grid; 128 x 64 longitude/latitude; 49 levels; top level 1 hPa) | 500 km | NEMO3.4.1 (ORCA1 tripolar grid, 1 deg with refinement to 1/3 deg within 20 degrees of the equator; 361 x 290 longitude/latitude; 45 vertical levels; top grid cell 0-6.19 m) | 100 km | specified ice sheets | 500 km | interactive | specified oxidants for aerosols | CLASS3.6/CTEM1.2 | Canadian Ocean Ecosystem (CanOE) with OMIP prescribed carbon chemistry | LIM2
E3SM-1-0 | E3SM-Project LLNL UCI UCSB | 2018 | CFMIP CMIP DAMIP PAMIP ScenarioMIP | Published | E3SM 1.0 | E3SM 1.0 (Energy Exascale Earth System Model) | EAM (v1.0, cubed sphere spectral-element grid; 5400 elements with p=3; 1 deg average grid spacing; 90 x 90 x 6 longitude/latitude/cubeface; 72 levels; top level 0.1 hPa) | 100 km | MPAS-Ocean (v6.0, oEC60to30 unstructured SVTs mesh with 235160 cells and 714274 edges, variable resolution 60 km to 30 km; 60 levels; top grid cell 0-10 m) | 50 km | none | none | MAM4 with resuspension, marine organics, and secondary organics (same grid as atmos) | Troposphere specified oxidants for aerosols. Stratosphere linearized interactive ozone (LINOZ v2) (same grid as atmos) | ELM (v1.0, cubed sphere spectral-element grid; 5400 elements with p=3; 1 deg average grid spacing; 90 x 90 x 6 longitude/latitude/cubeface; satellite phenology mode), MOSART (v1.0, 0.5 degree latitude/longitude grid) | none | MPAS-Seaice (v6.0, same grid as ocean)
E3SM-1-1 | E3SM-Project RUBISCO | 2019 | C4MIP CMIP DAMIP LS3MIP ScenarioMIP | Published | E3SM 1.1 | E3SM 1.1 (Energy Exascale Earth System Model) | EAM (v1.1, cubed sphere spectral-element grid; 5400 elements with p=3; 1 deg average grid spacing; 90 x 90 x 6 longitude/latitude/cubeface; 72 levels; top level 0.1 hPa) | 100 km | MPAS-Ocean (v6.0, oEC60to30 unstructured SVTs mesh with 235160 cells and 714274 edges, variable resolution 60 km to 30 km; 60 levels; top grid cell 0-10 m) | 50 km | none | none | MAM4 with resuspension, marine organics, and secondary organics (same grid as atmos) | Troposphere specified oxidants for aerosols. Stratosphere linearized interactive ozone (LINOZ v2) (same grid as atmos) | ELM (v1.1, same grid as atmos; active biogeochemistry using the Converging Trophic Cascade plant and soil carbon and nutrient mechanisms to represent carbon, nitrogen and phosphorus cycles), MOSART (v1.1, 0.5 degree latitude/longitude grid) | BEC (Biogeochemical Elemental Cycling model, NPZD-type with C/N/P/Fe/Si/O; same grid as ocean) | MPAS-Seaice (v6.0; same grid as ocean)
E3SM-1-1-ECA | E3SM-Project | 2019 | C4MIP CMIP ScenarioMIP | Published | E3SM 1.1 ECA | E3SM 1.1 (Energy Exascale Earth System Model) with an experimental land BGC ECA configuration | EAM (v1.1, cubed sphere spectral-element grid; 5400 elements with p=3; 1 deg average grid spacing; 90 x 90 x 6 longitude/latitude/cubeface; 72 levels; top level 0.1 hPa) | 100 km | MPAS-Ocean (v6.0, oEC60to30 unstructured SVTs mesh with 235160 cells and 714274 edges, variable resolution 60 km to 30 km; 60 levels; top grid cell 0-10 m) | 50 km | none | none | MAM4 with resuspension, marine organics, and secondary organics (same grid as atmos) | Troposphere specified oxidants for aerosols. Stratosphere linearized interactive ozone (LINOZ v2) (same grid as atmos) | ELM (v1.1, same as atmos; active biogeochemistry using the Equilibrium Chemistry Approximation to represent plant and soil carbon and nutrient mechanisms especially carbon, nitrogen and phosphorus limitation), MOSART (v1.1, 0.5 degree latitude/longitude grid) | BEC (Biogeochemical Elemental Cycling model, NPZD-type with C/N/P/Fe/Si/O; same grid as ocean) | MPAS-Seaice (v6.0; same grid as ocean)
E3SM-2-0 | E3SM-Project | 2022 | CFMIP CMIP DAMIP RFMIP ScenarioMIP | Published | E3SM 2.0 | E3SM 2.0 (Energy Exascale Earth System Model) | EAM (v2.0, cubed sphere spectral-element grid; 5400 elements, 30x30 per cube face. Dynamics: degree 3 (p=3) polynomials within each spectral element, 112 km average resolution. Physics: 2x2 finite volume cells within each spectral element, 1.5 degree (168 km) average grid spacing; 72 vertical layers; top level 60 km) | 100 km | MPAS-Ocean (E3SMv2.0, EC30to60E2r2 unstructured SVTs mesh with 236853 cells, 719506 edges, variable resolution 60 to 30 km; 60 levels; top grid cell 0-10 m) | 50 km | none | none | MAM4 with new resuspension, marine organics, secondary organics, and dust (atmos grid) | Troposphere specified oxidants (except passive ozone with the lower boundary sink) for aerosols. Stratosphere linearized interactive ozone (LINOZ v2) (atmos grid) | ELM (v1.0, satellite phenology mode, atmos grid), MOSART (v1.0, 0.5 degree latitude/longitude) | none | MPAS-Seaice (E3SMv2.0, ocean grid; 5 ice categories; 7 ice, 5 snow layers)
E3SM-2-0-NARRM | E3SM-Project | 2022 | CMIP | Published | E3SM 2.0 NARRM | E3SM 2.0 NARRM (Energy Exascale Earth System Model version 2.0 North American Regionally Refined Model) | EAM (v2.0, Dynamics: cubed sphere spectral-element grid, 130,088 columns; Physics: 2x2 finite volume cells within each spectral element, 57,816 columns. N. American (NA): 25 to 100 km; outside ~100 km. 72 vertical layers w/ top at 60 km) | 100 km | MPAS-Ocean (E3SMv2.0, WC14to60E2r5 unstructured SCVTs mesh with 407420 cells, 1240672 edges, NA: ~14 km; outside: 30 to 60 km; 60 levels; top grid cell 0-10 m) | 50 km | none | none | MAM4 w/ new resuspension, marine organics, secondary organics, and dust (atmos grid) | Troposphere specified oxidants (except passive ozone with the lower boundary sink) for aerosols. Stratosphere linearized interactive ozone (LINOZ v2) (atmos grid) | ELM (v1.0, satellite phenology mode, atmos grid), MOSART (v1.0, 0.125 degree latitude/longitude) | none | MPAS-Seaice (E3SMv2.0, ocean grid, variable resolution 30 to 60 km; 5 ice categories; 7 ice, 5 snow layers)
E3SM-2-1 | E3SM-Project | 2024 | CMIP | Published | E3SM 2.1 | E3SM 2.1 (Energy Exascale Earth System Model) | EAM (E3SMv2.1, cubed sphere spectral-element; 5400 els., 30x30 per cube face. Dynamics: degree 3 (p=3) polynomials within each spectral els., 112 km ave. resolution. Physics: 2x2 finite volume cells within each spectral els., 1.5 degree (168 km) average grid spacing; 72 vertical layers w/ top at 60 km) | 100 km | MPAS-Ocean (E3SMv2.1, EC30to60E2r2 unstructured SVTs mesh with 236853 cells and 719506 edges, variable resolution 60 km to 30 km; 60 levels; top grid cell 0-10 m) | 50 km | none | none | MAM4 w/ new resuspension, marine organics, secondary organics, and dust (atmos physics grid) | Troposphere specified oxidants (except passive ozone with the lower boundary sink) for aerosols. Stratosphere linearized interactive ozone (LINOZ v2) (atmos physics grid) | ELM (E3SMv2.1, atmos physics grid, satellite phenology mode), MOSART (E3SMv2.1, 0.5 deg lat/lon grid) | none | MPAS-Seaice (E3SMv2.1, MPAS-Ocean grid; 5 ice categories, 7 ice layers, 5 snow layers)
EC-Earth3 | EC-Earth-Consortium | 2019 | CMIP CORDEX DAMIP DCPP DynVarMIP LS3MIP OMIP PAMIP PMIP RFMIP SIMIP ScenarioMIP VIACSAB VolMIP | Published | EC-Earth3 | EC Earth 3.3 | IFS cy36r4 (TL255, linearly reduced Gaussian grid equivalent to 512 x 256 longitude/latitude; 91 levels; top level 0.01 hPa) | 100 km | NEMO3.6 (ORCA1 tripolar primarily 1 deg with meridional refinement down to 1/3 degree in the tropics; 362 x 292 longitude/latitude; 75 levels; top grid cell 0-1 m) | 100 km | none | none | none | none | HTESSEL (land surface scheme built in IFS) | none | LIM3
EC-Earth3-AerChem | EC-Earth-Consortium | 2019 | AerChemMIP CMIP RFMIP ScenarioMIP | Published | EC-Earth3-AerChem | EC-Earth3-AerChem | IFS cy36r4 (TL255, linearly reduced Gaussian grid equivalent to 512 x 256 longitude/latitude; 91 levels; top level 0.01 hPa) | 100 km | NEMO3.6 (ORCA1 tripolar primarily 1 degree with meridional refinement down to 1/3 degree in the tropics; 362 x 292 longitude/latitude; 75 levels; top grid cell 0-1 m) | 100 km | none | none | TM5 (3 x 2 degrees; 120 x 90 longitude/latitude; 34 levels; top level: 0.1 hPa) | TM5 (3 x 2 degrees; 120 x 90 longitude/latitude; 34 levels; top level: 0.1 hPa) | HTESSEL (land surface scheme built in IFS) | none | LIM3
EC-Earth3-CC | EC-Earth-Consortium | 2019 | C4MIP CDRMIP CMIP DCPP LUMIP OMIP ScenarioMIP | Published | EC-Earth3-CC | EC-Earth3-CC | IFS cy36r4 (TL255, linearly reduced Gaussian grid equivalent to 512 x 256 longitude/latitude; 91 levels; top level 0.01 hPa) | 100 km | NEMO3.6 (ORCA1 tripolar primarily 1 degree with meridional refinement down to 1/3 degree in the tropics; 362 x 292 longitude/latitude; 75 levels; top grid cell 0-1 m) | 100 km | none | none | none | TM5 (3 x 2 degrees; 120 x 90 longitude/latitude; 34 levels; top level: 0.1 hPa) | HTESSEL (land surface scheme built in IFS) and LPJ-GUESS v4 | PISCES v2 | LIM3
EC-Earth3-ESM-1 | EC-Earth-Consortium | 2024 | C4MIP CDRMIP CMIP DCPP LUMIP OMIP ScenarioMIP | Published | EC-Earth3-ESM-1 | EC-Earth3-ESM-1 | IFS cy36r4 (TL255, linearly reduced Gaussian grid equivalent to 512 x 256 longitude/latitude; 91 levels; top level 0.01 hPa) and co2box v1.0 (CO2 box model; global grid) | 100 km | NEMO3.6 (ORCA1 tripolar primarily 1 degree with meridional refinement down to 1/3 degree in the tropics; 362 x 292 longitude/latitude; 75 levels; top grid cell 0-1 m) and MWE v1.0 (Melt Water Emulator; same grid as ocean for Antarctic surroundings) | 100 km | PISM v1.2 (5 km x 5 km for Greenland, 31 levels) | 5 km | none | none | HTESSEL (land surface scheme built in IFS) and LPJ-GUESS v4.1.2 (same grid as atmos) | PISCES v2 (same grid as ocean) | LIM3 (same grid as ocean)
EC-Earth3-HR | EC-Earth-Consortium | 2019 | CMIP DCPP HighResMIP | Published | EC-Earth3-HR | EC-Earth3-HR | IFS cy36r4 (TL511, linearly reduced Gaussian grid equivalent to 1024 x 512 longitude/latitude; 91 levels; top level 0.01 hPa) | 50 km | NEMO3.6 (ORCA025 tripolar primarily 0.25 degrees; 1442 x 1921 longitude/latitude; 75 levels; top grid cell 0-1 m) | 25 km | none | none | none | none | HTESSEL (land surface scheme built in IFS) | none | LIM3
EC-Earth3-LR | EC-Earth-Consortium | 2019 | CMIP PMIP | Published | EC-Earth3-LR | EC-Earth3-LR | IFS cy36r4 (TL159, linearly reduced Gaussian grid equivalent to 320 x 160 longitude/latitude; 62 levels; top level 5 hPa) | 250 km | NEMO3.6 (ORCA1 tripolar primarily 1 degree with meridional refinement down to 1/3 degree in the tropics; 362 x 292 longitude/latitude; 75 levels; top grid cell 0-1 m) | 100 km | none | none | none | none | HTESSEL (land surface scheme built in IFS) | none | LIM3
EC-Earth3-Veg | EC-Earth-Consortium | 2019 | CDRMIP CMIP CORDEX LS3MIP LUMIP PMIP ScenarioMIP | Published | EC-Earth3-Veg | EC-Earth3-Veg | IFS cy36r4 (TL255, linearly reduced Gaussian grid equivalent to 512 x 256 longitude/latitude; 91 levels; top level 0.01 hPa) | 100 km | NEMO3.6 (ORCA1 tripolar primarily 1 degree with meridional refinement down to 1/3 degree in the tropics; 362 x 292 longitude/latitude; 75 levels; top grid cell 0-1 m) | 100 km | none | none | none | none | HTESSEL (land surface scheme built in IFS) and LPJ-GUESS v4 | none | LIM3
EC-Earth3-Veg-LR | EC-Earth-Consortium | 2019 | CMIP PMIP ScenarioMIP | Published | EC-Earth3-Veg-LR | EC-Earth3-Veg-LR | IFS cy36r4 (TL159, linearly reduced Gaussian grid equivalent to 320 x 160 longitude/latitude; 62 levels; top level 5 hPa) | 250 km | NEMO3.6 (ORCA1 tripolar primarily 1 degree with meridional refinement down to 1/3 degree in the tropics; 362 x 292 longitude/latitude; 75 levels; top grid cell 0-1 m) | 100 km | none | none | none | none | HTESSEL (land surface scheme built in IFS) and LPJ-GUESS v4 | none | LIM3
EC-Earth3P | EC-Earth-Consortium | 2017 | CMIP HighResMIP | Published | EC-Earth3P | EC-Earth 3.2 in PRIMAVERA | IFS cy36r4 (TL255, linearly reduced Gaussian grid equivalent to 512 x 256 longitude/latitude; 91 levels; top level 0.01 hPa) | 100 km | NEMO3.6 (ORCA1 tripolar primarily 1 degree with meridional refinement down to 1/3 degree in the tropics; 362 x 292 longitude/latitude; 75 levels; top grid cell 0-1 m) | 100 km | none | none | none | none | HTESSEL (land surface scheme built in IFS) | none | LIM3
EC-Earth3P-HR | EC-Earth-Consortium | 2017 | HighResMIP | Published | EC-Earth3P-HR | EC-Earth3P-HR in PRIMAVERA | IFS cy36r4 (TL511, linearly reduced Gaussian grid equivalent to 1024 x 512 longitude/latitude; 91 levels; top level 0.01 hPa) | 50 km | NEMO3.6 (ORCA025; tripolar primarily 0.25 degrees; 1442 x 1921 longitude/latitude; 75 levels; top grid cell 0-1 m) | 25 km | none | none | none | none | HTESSEL (land surface scheme built in IFS) | none | LIM3
EC-Earth3P-VHR | EC-Earth-Consortium | 2017 | HighResMIP | Published | EC-Earth3P-VHR | EC-Earth3P-VHR in PRIMAVERA | IFS cy36r4 (TL1279, linearly reduced Gaussian grid equivalent to 2560 x 1280 longitude/latitude; 91 levels; top level 0.01 hPa) | 25 km | NEMO3.6 (ORCA012 tripolar primarily 0.08 degrees; 4322 x 3059 longitude/latitude; 75 levels; top grid cell 0-1 m) | 10 km | none | none | none | none | HTESSEL (land surface scheme built in IFS) | none | LIM3
ECMWF-IFS-HR | ECMWF | 2017 | HighResMIP | Published | ECMWF-IFS-HR | ECMWF-IFS-HR (25 km atmosphere and 25 km ocean) | IFS (IFS CY43R1, Tco399, cubic octahedral reduced Gaussian grid equivalent to 1600 x 800 longitude/latitude; 91 levels; top level 0.01 hPa) | 25 km | NEMO3.4 (NEMO v3.4; ORCA025 tripolar grid; 1442 x 1021 longitude/latitude; 75 levels; top grid cell 0-1 m) | 25 km | none | none | none | none | HTESSEL (as implemented in IFS CY43R1) | none | LIM2 (LIM v2; ORCA025 tripolar grid; 1442 x 1021 longitude/latitude)
ECMWF-IFS-LR | ECMWF | 2017 | HighResMIP | Published | ECMWF-IFS-LR | ECMWF-IFS-LR (50 km atmosphere and 100 km ocean) | IFS (IFS CY43R1, Tco199, cubic octahedral reduced Gaussian grid equivalent to 800 x 400 longitude/latitude; 91 levels; top level 0.01 hPa) | 50 km | NEMO3.4 (NEMO v3.4; ORCA1 tripolar grid; 362 x 292 longitude/latitude; 75 levels; top grid cell 0-1 m) | 100 km | none | none | none | none | HTESSEL (as implemented in IFS CY43R1) | none | LIM2 (LIM v2; ORCA1 tripolar grid; 362 x 292 longitude/latitude)
ECMWF-IFS-MR | ECMWF | 2017 | HighResMIP | Published | ECMWF-IFS-MR | ECMWF-IFS-MR (50 km atmosphere and 25 km ocean) | IFS (IFS CY43R1, Tco199, cubic octahedral reduced Gaussian grid equivalent to 800 x 400 longitude/latitude; 91 levels; top level 0.01 hPa) | 50 km | NEMO3.4 (NEMO v3.4; ORCA025 tripolar grid; 1442 x 1021 longitude/latitude; 75 levels; top grid cell 0-1 m) | 25 km | none | none | none | none | HTESSEL (as implemented in IFS CY43R1) | none | LIM2 (LIM v2; ORCA025 tripolar grid; 1442 x 1021 longitude/latitude)
FGOALS-f3-H | CAS | 2017 | CMIP HighResMIP OMIP | Published | FGOALS-f3-H | FGOALS-f3-H | FAMIL2.2 (Cubed-sphere, c384; 1440 x 720 longitude/latitude; 32 levels; top level 2.16 hPa) | 25 km | LICOM3.0 (LICOM3.0, tripolar primarily 0.1deg; 3600 x 2302 longitude/latitude; 55 levels; top grid cell 0-5 m) | 10 km | none | none | none | none | CLM4.0 | none | CICE4.0
FGOALS-f3-L | CAS | 2017 | CMIP DCPP GMMIP HighResMIP OMIP PAMIP PMIP SIMIP ScenarioMIP | Published | FGOALS-f3-L | FGOALS-f3-L | FAMIL2.2 (Cubed-sphere, c96; 360 x 180 longitude/latitude; 32 levels; top level 2.16 hPa) | 100 km | LICOM3.0 (LICOM3.0, tripolar primarily 1deg; 360 x 218 longitude/latitude; 30 levels; top grid cell 0-10 m) | 100 km | none | none | none | none | CLM4.0 | none | CICE4.0
FGOALS-g3 | CAS | 2017 | CMIP CORDEX DAMIP DCPP FAFMIP GMMIP LS3MIP OMIP PMIP SIMIP ScenarioMIP | Published | FGOALS-g3 | FGOALS-g3 | GAMIL3 (180 x 80 longitude/latitude; 26 levels; top level 2.19hPa) | 250 km | LICOM3.0 (LICOM3.0, tripolar primarily 1deg; 360 x 218 longitude/latitude; 30 levels; top grid cell 0-10 m) | 100 km | none | none | none | none | CAS-LSM | none | CICE4.0
FIO-ESM-2-0 | FIO-QLNM | 2018 | CMIP DCPP GMMIP OMIP ScenarioMIP SIMIP | Published | FIO-ESM 2.0 | FIO-ESM 2.0 | CAM4 (0.9x1.25 finite volume grid; 192 x 288 longitude/latitude; 26 levels; top level ~2 hPa) | 100 km | POP2-W (POP2 coupled with MASNUM surface wave model, Displaced Pole; 320 x 384 longitude/latitude; 60 levels; top grid cell 0-10 m) | 100 km | none | none | Prescribed monthly fields | none | CLM4.0 (same grid at atmos) | none | CICE4.0 (same grid as ocean)
GFDL-AM4 | NOAA-GFDL | 2018 | CMIP | Published | GFDL-AM4 | GFDL-AM4 | GFDL-AM4.0 (Cubed-sphere (c96) - 1 degree nominal horizontal resolution; 360 x 180 longitude/latitude; 33 levels; top level 1 hPa) | 100 km | none | none | GFDL-LM4.0 | 100 km | interactive | fast chemistry, aerosol only | GFDL-LM4.0 | none | none
GFDL-CM4 | NOAA-GFDL | 2018 | CFMIP CMIP DAMIP DynVarMIP FAFMIP GMMIP OMIP RFMIP ScenarioMIP | Published | GFDL-CM4 | GFDL-CM4 | GFDL-AM4.0.1 (Cubed-sphere (c96) - 1 degree nominal horizontal resolution; 360 x 180 longitude/latitude; 33 levels; top level 1 hPa) | 100 km | GFDL-OM4p25 (GFDL-MOM6, tripolar - nominal 0.25 deg; 1440 x 1080 longitude/latitude; 75 levels; top grid cell 0-2 m) | 25 km | GFDL-LM4.0.1 | 100 km | interactive | fast chemistry, aerosol only | GFDL-LM4.0.1 (1 degree nominal horizontal resolution; 360 x 180 longitude/latitude; 20 levels; bottom level 10m); land-Veg:unnamed (dynamic vegetation, dynamic land use); land-Hydro:unnamed (soil water and ice, multi-layer snow, rivers and lakes) | GFDL-BLINGv2 | GFDL-SIM4p25 (GFDL-SIS2.0, tripolar - nominal 0.25 deg; 1440 x 1080 longitude/latitude; 5 layers; 5 thickness categories)
GFDL-CM4C192 | NOAA-GFDL | 2018 | HighResMIP | Published | GFDL-CM4C192 | GFDL-CM4C192 | GFDL-AM4C192 (Cubed-sphere (c192) - 0.5 degree nominal horizontal resolution; 720 x 360 longitude/latitude; 33 levels; top level 1 hPa) | 50 km | GFDL-OM4p25 (GFDL-MOM6, tripolar - nominal 0.25 deg; 1440 x 1080 longitude/latitude; 75 levels; top grid cell 0-2 m) | 25 km | GFDL-LM4.0.1 | 50 km | interactive | fast chemistry, aerosol only | GFDL-LM4.0.1 | none | GFDL-SIM4p25 (GFDL-SIS2.0, tripolar - nominal 0.25 deg; 1440 x 1080 longitude/latitude; 5 layers; 5 thickness categories)
GFDL-ESM2M | NOAA-GFDL | 2012 | FAFMIP | Published | GFDL-ESM2M | GFDL-ESM2M | GFDL-AM2 (144 x 90 longitude/latitude; 24 levels; top level 1 hPa) | 250 km | GFDL-MOM4p1 (tripolar - nominal 1 deg; 360 x 200 longitude/latitude; 50 levels; top grid cell 0-10 m) | 100 km | GFDL-LM3.0 | 250 km | prescribed | prescribed | GFDL-LM3.0 | GFDL-TOPAZ2 | GFDL-SIM2 (GFDL-SIS, tripolar - nominal 1 deg; 360 x 200 longitude/latitude; 3 layers; 5 thickness categories)
GFDL-ESM4 | NOAA-GFDL | 2018 | AerChemMIP C4MIP CDRMIP CMIP DAMIP DynVarMIP FAFMIP LUMIP RFMIP ScenarioMIP | Published | GFDL-ESM4 | GFDL-ESM4 | GFDL-AM4.1 (Cubed-sphere (c96) - 1 degree nominal horizontal resolution; 360 x 180 longitude/latitude; 49 levels; top level 1 Pa) | 100 km | GFDL-OM4p5 (GFDL-MOM6, tripolar - nominal 0.5 deg; 720 x 576 longitude/latitude; 75 levels; top grid cell 0-2 m) | 50 km | GFDL-LM4.1 | 100 km | interactive | GFDL-ATMCHEM4.1 (full atmospheric chemistry) | GFDL-LM4.1 | GFDL-COBALTv2 | GFDL-SIM4p5 (GFDL-SIS2.0, tripolar - nominal 0.5 deg; 720 x 576 longitude/latitude; 5 layers; 5 thickness categories)
GFDL-GRTCODE | NOAA-GFDL | 2019 | RFMIP | Published | GFDL-GRTCODE | GFDL GPU radiative transfer code with two stream solver (March 2019) | none | none | none | none | none | none | none | none | none | none | none
GFDL-OM4p5B | NOAA-GFDL | 2018 | OMIP | Published | GFDL-OM4p5B | GFDL-OM4p5B | none | none | GFDL-OM4p5 (GFDL-MOM6, tripolar - nominal 0.5 deg; 720 x 576 longitude/latitude; 75 levels; top grid cell 0-2 m) | 50 km | none | none | none | none | none | GFDL-BLINGv2 | GFDL-SIM4p5 (GFDL-SIS2.0, tripolar - nominal 0.5 deg; 720 x 576 longitude/latitude; 5 layers; 5 thickness categories)
GFDL-RFM-DISORT | NOAA-GFDL | 2019 | RFMIP | Published | GFDL-RFM-DISORT | GFDL Reference Forward Model Line-by-Line with DISORT solver (March 2019) | none | none | none | none | none | none | none | none | none | none | none
GISS-E2-1-G | NASA-GISS | 2019 | AerChemMIP C4MIP CFMIP CMIP DAMIP DynVarMIP FAFMIP GMMIP ISMIP6 LS3MIP LUMIP OMIP PAMIP PMIP RFMIP SIMIP ScenarioMIP VIACSAB VolMIP | Published | GISS-E2.1G | GISS-E2.1G | GISS-E2.1 (2.5x2 degree; 144 x 90 longitude/latitude; 40 levels; top level 0.1 hPa) | 250 km | GISS Ocean (GO1, 1 degree; 360 x 180 longitude/latitude; 40 levels; top grid cell 0-10 m) | 100 km | none | none | Varies with physics-version (p==1 none, p==3 OMA, p==4 TOMAS, p==5 MATRIX) | Varies with physics-version (p==1 Non-interactive, p>1 GPUCCINI) | GISS LSM | none | GISS SI
GISS-E2-1-G-CC | NASA-GISS | 2019 | C4MIP CMIP ScenarioMIP | Published | GISS-E2-1-G-CC | GISS-E2-1-G-CC | GISS-E2.1 (2 x 2.5 degrees; 144 x 90 longitude/latitude; 40 levels; top level 0.1 hPa) | 250 km | GISS Ocean (1 deg; 360 x 180 longitude/latitude; 40 levels; top grid cell 0-10m) | 100 km | Fixed | 250 km | varies with physics-version (p==1 none, p==3 OMA, p==4 TOMAS, p==5 MATRIX) | varies with physics-version (p==1 Non-interactive, p>1 GPUCCINI) | GISS LSM | NOBM (NASA Ocean Biogeochemistry Model; same grid as ocean) | GISS SI (same grid as ocean)
GISS-E2-1-H | NASA-GISS | 2019 | AerChemMIP CFMIP CMIP OMIP PAMIP SIMIP ScenarioMIP | Published | GISS-E2.1H | GISS-E2.1H | GISS-E2.1 (2.5x2 degree; 144 x 90 longitude/latitude; 40 levels; top level 0.1 hPa) | 250 km | HYCOM Ocean (~1 degree tripolar grid; 360 x 180 longitude/latitude; 33 levels; top grid cell 0-10 m) | 100 km | none | none | Varies with physics-version (p==1 none, p==3 OMA, p==4 TOMAS, p==5 MATRIX) | Varies with physics-version (p==1 Non-interactive, p>1 GPUCCINI) | GISS LSM | none | GISS SI
GISS-E2-2-G | NASA-GISS | 2019 | AerChemMIP CFMIP CMIP DAMIP DynVarMIP FAFMIP GMMIP ISMIP6 LS3MIP LUMIP OMIP PAMIP PMIP RFMIP SIMIP ScenarioMIP VIACSAB VolMIP | Published | GISS-E2-2-G | GISS-E2-2-G | GISS-E2.2 (High-top, 2 x 2.5 degrees; 144 x 90 longitude/latitude; 102 levels; top level 0.002 hPa) | 250 km | GISS Ocean (GO1, 1 degree; 360 x 180 longitude/latitude; 40 levels; top grid cell 0-10m) | 100 km | Fixed | 250 km | varies with physics-version (p==1 none, p==3 OMA, p==4 TOMAS, p==5 MATRIX) | varies with physics-version (p==1 Non-interactive, p>1 GPUCCINI) | GISS LSM | none | GISS SI
GISS-E2-2-H | NASA-GISS | 2021 | CFMIP CMIP SIMIP ScenarioMIP | Published | GISS-E2.2H | GISS-E2.2H | GISS-E2.2 (High Top, 2.5x2 degree; 144 x 90 longitude/latitude; 102 levels; top level 0.002 hPa) | 250 km | HYCOM Ocean (~1 degree tripolar grid; 360 x 180 longitude/latitude; 33 levels; top grid cell 0-10 m) | 100 km | none | none | Varies with physics-version (p==1 none, p==3 OMA, p==4 TOMAS, p==5 MATRIX) | Varies with physics-version (p==1 Non-interactive, p>1 GPUCCINI) | GISS LSM | none | GISS SI (same grid as atmos)
GISS-E3-G | NASA-GISS | 2020 | AerChemMIP C4MIP CFMIP CMIP DAMIP DynVarMIP FAFMIP GMMIP ISMIP6 LS3MIP LUMIP OMIP PAMIP PMIP RFMIP SIMIP ScenarioMIP VIACSAB VolMIP | Published | GISS-E3-G | GISS-E3-G | GISS-E3 (Cubed sphere, C90; 90 x 90 x 6 gridboxes/cubeface, grid resolution aligns with longitude/latitude along central lines for each cubeface; 102 levels; top level 0.002 hPa) | 100 km | GISS Ocean (1 degree; 360 x 180 longitude/latitude; 32 levels; top grid cell 0-10 m) | 100 km | none | none | Varies with physics-version (p==1 none, p==3 OMA, p==4 TOMAS, p==5 MATRIX) | Varies with physics-version (p==1 Non-interactive, p>1 GPUCCINI) | GISS LSM | none | GISS SI
HadGEM3-GC31-HH | MOHC NERC | 2016 | CMIP HighResMIP | Published | HadGEM3-GC31-HH | HadGEM3-GC3.1-N512ORCA12 | MetUM-HadGEM3-GA7.1 (N512; 1024 x 768 longitude/latitude; 85 levels; top level 85 km) | 50 km | NEMO-HadGEM3-GO6.0 (eORCA12 tripolar primarily 1/12 deg; 4320 x 3604 longitude/latitude; 75 levels; top grid cell 0-1 m) | 10 km | none | none | UKCA-GLOMAP-mode | none | JULES-HadGEM3-GL7.1 | none | CICE-HadGEM3-GSI8 (eORCA12 tripolar primarily 1/12 deg; 4320 x 3604 longitude/latitude)
HadGEM3-GC31-HM | MOHC NERC | 2016 | CMIP HighResMIP | Published | HadGEM3-GC31-HM | HadGEM3-GC3.1-N512ORCA025 | MetUM-HadGEM3-GA7.1 (N512; 1024 x 768 longitude/latitude; 85 levels; top level 85 km) | 50 km | NEMO-HadGEM3-GO6.0 (eORCA025 tripolar primarily 0.25 deg; 1440 x 1205 longitude/latitude; 75 levels; top grid cell 0-1 m) | 25 km | none | none | UKCA-GLOMAP-mode | none | JULES-HadGEM3-GL7.1 | none | CICE-HadGEM3-GSI8 (eORCA025 tripolar primarily 0.25 deg; 1440 x 1205 longitude/latitude)
HadGEM3-GC31-LL | MOHC NERC | 2016 | CFMIP CMIP DAMIP FAFMIP HighResMIP LS3MIP LUMIP PMIP RFMIP ScenarioMIP | Published | HadGEM3-GC31-LL | HadGEM3-GC3.1-N96ORCA1 | MetUM-HadGEM3-GA7.1 (N96; 192 x 144 longitude/latitude; 85 levels; top level 85 km) | 250 km | NEMO-HadGEM3-GO6.0 (eORCA1 tripolar primarily 1 deg with meridional refinement down to 1/3 degree in the tropics; 360 x 330 longitude/latitude; 75 levels; top grid cell 0-1 m) | 100 km | none | none | UKCA-GLOMAP-mode | none | JULES-HadGEM3-GL7.1 | none | CICE-HadGEM3-GSI8 (eORCA1 tripolar primarily 1 deg; 360 x 330 longitude/latitude)
HadGEM3-GC31-LM | MOHC | 2016 | CMIP HighResMIP | Published | HadGEM3-GC31-LM | HadGEM3-GC3.1-N96ORCA025 | MetUM-HadGEM3-GA7.1 (N96; 192 x 144 longitude/latitude; 85 levels; top level 85 km) | 250 km | NEMO-HadGEM3-GO6.0 (eORCA025 tripolar primarily 0.25 deg; 1440 x 1205 longitude/latitude; 75 levels; top grid cell 0-1 m) | 25 km | none | none | UKCA-GLOMAP-mode | none | JULES-HadGEM3-GL7.1 | none | CICE-HadGEM3-GSI8 (eORCA025 tripolar primarily 0.25 deg; 1440 x 1205 longitude/latitude)
HadGEM3-GC31-MH | MOHC | 2016 | CMIP HighResMIP | Published | HadGEM3-GC31-MH | HadGEM3-GC3.1-N216ORCA12 | MetUM-HadGEM3-GA7.1 (N216; 432 x 324 longitude/latitude; 85 levels; top level 85 km) | 100 km | NEMO-HadGEM3-GO6.0 (eORCA12 tripolar primarily 1/12 deg; 4320 x 3604 longitude/latitude; 75 levels; top grid cell 0-1 m) | 10 km | none | none | UKCA-GLOMAP-mode | none | JULES-HadGEM3-GL7.1 | none | CICE-HadGEM3-GSI8 (eORCA12 tripolar primarily 1/12 deg; 4320 x 3604 longitude/latitude)
HadGEM3-GC31-MM | MOHC | 2016 | CMIP DCPP GMMIP HighResMIP LS3MIP OMIP PAMIP ScenarioMIP | Published | HadGEM3-GC31-MM | HadGEM3-GC3.1-N216ORCA025 | MetUM-HadGEM3-GA7.1 (N216; 432 x 324 longitude/latitude; 85 levels; top level 85 km) | 100 km | NEMO-HadGEM3-GO6.0 (eORCA025 tripolar primarily 0.25 deg; 1440 x 1205 longitude/latitude; 75 levels; top grid cell 0-1 m) | 25 km | none | none | UKCA-GLOMAP-mode | none | JULES-HadGEM3-GL7.1 | none | CICE-HadGEM3-GSI8 (eORCA025 tripolar primarily 0.25 deg; 1440 x 1205 longitude/latitude)
HiRAM-SIT-HR | AS-RCEC | 2018 | HighResMIP | Published | HiRAM-SIT-HR | HiRAM Coupling 1-D SIT (25 km atmosphere and 25 km ocean) | GFDL-HiRAM (Cubed-sphere (c384) - 0.25 degree nominal horizontal resolution; 1536 x 768 longitude/latitude; 32 levels; top level 1 hPa) | 25 km | SIT (1-D, tripolar - nominal 0.25 deg; 1440 x 1080 longitude/latitude; 50 levels with skin layer and 1 m resolution for uppermost 10 m) | 25 km | none | none | none | none | GFDL-LM3 (same grid as atmos) | none | none
HiRAM-SIT-LR | AS-RCEC | 2018 | HighResMIP | Published | HiRAM-SIT-LR | HiRAM Coupling 1-D SIT (50 km atmosphere and 25 km ocean) | GFDL-HiRAM (Cubed-sphere (c192) - 0.5 degree nominal horizontal resolution; 768 x 384 longitude/latitude; 32 levels; top level 1 hPa) | 50 km | SIT (1-D, tripolar - nominal 0.25 deg; 1440 x 1080 longitude/latitude; 50 levels with skin layer and 1 m resolution for uppermost 10 m) | 25 km | none | none | none | none | GFDL-LM3 (same grid as atmos) | none | none
ICON-ESM-LR | MPI-M | 2017 | CMIP OMIP SIMIP | Published | ICON-ESM-LR | ICON-ESM-LR | ICON-A (icosahedral/triangles; 160 km; 47 levels; top level 80 km) | 250 km | ICON-O (icosahedral/triangles; 40 km; 40 levels; top grid cell 0-12 m) | 50 km | none/prescribed | none | none, prescribed MACv2-SP | none | JSBACH4.20 | HAMOCC | unnamed (thermodynamic (Semtner zero-layer) dynamic (Hibler 79) sea ice model)
IITM-ESM | CCCR-IITM | 2015 | CMIP GMMIP ScenarioMIP | Published | IITM-ESM | IITM-ESM | IITM-GFSv1 (T62L64, Linearly Reduced Gaussian Grid; 192 x 94 longitude/latitude; 64 levels; top level 0.2 mb) | 250 km | MOM4p1 (tripolar, primarily 1deg; 360 x 200 longitude/latitude; 50 levels; top grid cell 0-10 m) | 100 km | none | none | prescribed MAC-v2 | none | NOAH LSMv2.7.1 | TOPAZv2.0 | SISv1.0
INM-CM4-8 | INM | 2016 | CMIP PMIP ScenarioMIP | Published | INM-CM4-8 | INM-CM4-8 | INM-AM4-8 (2x1.5; 180 x 120 longitude/latitude; 21 levels; top level sigma = 0.01) | 100 km | INM-OM5 (North Pole shifted to 60N, 90E; 360 x 318 longitude/latitude; 40 levels; sigma vertical coordinate) | 100 km | none | none | INM-AER1 | none | INM-LND1 | none | INM-ICE1
INM-CM5-0 | INM | 2016 | CMIP ScenarioMIP | Published | INM-CM5-0 | INM-CM5-0 | INM-AM5-0 (2x1.5; 180 x 120 longitude/latitude; 73 levels; top level sigma = 0.0002) | 100 km | INM-OM5 (North Pole shifted to 60N, 90E. 0.5x0.25; 720 x 720 longitude/latitude; 40 levels; vertical sigma coordinate) | 50 km | none | none | INM-AER1 | none | INM-LND1 | none | INM-ICE1
INM-CM5-H | INM | 2016 | CMIP HighResMIP | Published | INM-CM5-H | INM-CM5-H | INM-AM5-H (0.67x0.5; 540 x 360 longitude/latitude; 73 levels; top level sigma = 0.0002) | 50 km | INM-OM5-H (North Pole shifted to 60N, 90E. 0.167x0.125; 2160x1440 longitude/latitude; 40 levels; vertical sigma coordinate) | 10 km | none | none | INM-AER1 | none | INM-LND1 | none | INM-ICE1
IPSL-CM5A2-INCA | IPSL | 2019 | AerChemMIP LUMIP ScenarioMIP | Published | IPSL-CM5A2-INCA | IPSL-CM5A2-INCA | LMDZ (APv5; 96 x 96 longitude/latitude; 39 levels; top level 80000 m) | 500 km | NEMO-OPA (v3.6, ORCA2 tripolar primarily 2deg; 182 x 149 longitude/latitude; 31 levels; top grid cell 0-10 m) | 250 km | none | none | INCA v6 NMHC-AER-S | INCA v6 NMHC-AER-S | ORCHIDEE (IPSLCM5A2.1, Water/Carbon/Energy mode) | NEMO-PISCES | NEMO-LIM2
IPSL-CM6A-ATM-HR | IPSL | 2018 | HighResMIP | Published | IPSL-CM6A-ATM-HR | IPSL-CM6A-ATM-HR | LMDZ (NPv6, N256; 512 x 360 longitude/latitude; 79 levels; top level 80000 m) | 50 km | none | none | none | none | none | none | ORCHIDEE (v2.0, Water/Carbon/Energy mode) | none | none
IPSL-CM6A-ATM-ICO-HR | IPSL | 2021 | HighResMIP | Published | IPSL-CM6A-ATM-ICO-HR | IPSL-CM6A-ATM-ICO-HR | DYNAMICO-LMDZ (NPv6; 256000-point icosahedral-hexagonal; 79 levels; top level 80000 m) | 50 km | none | none | none | none | none | none | ORCHIDEE (v2.2, Water/Carbon/Energy mode) | none | none
IPSL-CM6A-ATM-ICO-LR | IPSL | 2021 | HighResMIP | Published | IPSL-CM6A-ATM-ICO-LR | IPSL-CM6A-ATM-ICO-LR | DYNAMICO-LMDZ (NPv6; 16000-point icosahedral-hexagonal; 79 levels; top level 80000 m) | 250 km | none | none | none | none | none | none | ORCHIDEE (v2.2, Water/Carbon/Energy mode) | none | none
IPSL-CM6A-ATM-ICO-MR | IPSL | 2021 | HighResMIP | Published | IPSL-CM6A-ATM-ICO-MR | IPSL-CM6A-ATM-ICO-MR | DYNAMICO-LMDZ (NPv6; 64000-point icosahedral-hexagonal; 79 levels; top level 80000 m) | 100 km | none | none | none | none | none | none | ORCHIDEE (v2.2, Water/Carbon/Energy mode) | none | none
IPSL-CM6A-ATM-ICO-VHR | IPSL | 2021 | HighResMIP | Published | IPSL-CM6A-ATM-ICO-VHR | IPSL-CM6A-ATM-ICO-VHR | DYNAMICO-LMDZ (NPv6; 1024000-point icosahedral-hexagonal; 79 levels; top level 80000 m) | 25 km | none | none | none | none | none | none | ORCHIDEE (v2.2, Water/Carbon/Energy mode) | none | none
IPSL-CM6A-ATM-LR-REPROBUS | IPSL | 2021 | AerChemMIP | Published | IPSL-CM6A-ATM-LR-REPROBUS | IPSL-CM6A-ATM-LR-REPROBUS | LMDZ (NPv6 ; 144 x 143 longitude/latitude; 79 levels; top level 80000 m) | 250 km | none | none | none | none | LMDZ (NPv6 ; 144 x 143 longitude/latitude; 79 levels; top level 80000 m) | REPROBUS v6 (same grid as atmos) | none | none | none
IPSL-CM6A-LR | IPSL | 2017 | AerChemMIP C4MIP CDRMIP CFMIP CMIP DAMIP DCPP FAFMIP GMMIP GeoMIP HighResMIP LS3MIP LUMIP OMIP PAMIP PMIP RFMIP ScenarioMIP VolMIP | Published | IPSL-CM6A-LR | IPSL-CM6A-LR | LMDZ (NPv6, N96; 144 x 143 longitude/latitude; 79 levels; top level 80000 m) | 250 km | NEMO-OPA (eORCA1.3, tripolar primarily 1deg; 362 x 332 longitude/latitude; 75 levels; top grid cell 0-2 m) | 100 km | none | none | none | none | ORCHIDEE (v2.0, Water/Carbon/Energy mode) | NEMO-PISCES | NEMO-LIM3
IPSL-CM6A-LR-INCA | IPSL | 2019 | AerChemMIP RFMIP | Published | IPSL-CM6A-LR-INCA | IPSL-CM6A-LR-INCA | LMDZ (NPv6 ; 144 x 143 longitude/latitude; 79 levels; top level 80000 m) | 250 km | NEMO-OPA (eORCA1.3, tripolar primarily 1deg; 362 x 332 longitude/latitude; 75 levels; top grid cell 0-2 m) | 100 km | none | none | INCA v6 AER | none | ORCHIDEE (v2.0, Water/Carbon/Energy mode) | NEMO-PISCES | NEMO-LIM3
IPSL-CM6A-MR1 | IPSL | 2021 | CMIP | Published | IPSL-CM6A-MR1 | IPSL-CM6A-MR1 | LMDZ (NPv6; 256 x 256 longitude/latitude; 79 levels; top level 80000 m) | 100 km | NEMO-OPA (eORCA1.3, tripolar primarily 1deg; 362 x 332 longitude/latitude; 75 levels; top grid cell 0-2 m) | 100 km | none | none | none | none | ORCHIDEE (v2.2, Water/Carbon/Energy mode; same grid as atmos) | NEMO-PISCES (same grid as ocean) | NEMO-LIM3 (same grid as ocean)
KACE-1-0-G | NIMS-KMA | 2018 | CMIP ScenarioMIP | Published | KACE1.0-G | KACE1.0-GLOMAP | MetUM-HadGEM3-GA7.1 (N96; 192 x 144 longitude/latitude; 85 levels; top level 85 km) | 250 km | MOM4p1 (tripolar primarily 1deg; 360 x 200 longitude/latitude; 50 levels; top grid cell 0-10 m) | 100 km | none | none | UKCA-GLOMAP-mode | none | JULES-HadGEM3-GL7.1 | none | CICE-HadGEM3-GSI8 (tripolar primarily 1deg; 360 x 200 longitude/latitude)
KIOST-ESM | KIOST | 2018 | C4MIP CMIP DynVarMIP PMIP ScenarioMIP | Published | KIOST-ESM | KIOST Earth System Model v2 | GFDL-AM2.0 (cubed sphere (C48); 192 x 96 longitude/latitude; 32 vertical levels; top level 2 hPa) | 250 km | GFDL-MOM5.0 (tripolar - nominal 1.0 deg; 360 x 200 longitude/latitude; 52 levels; top grid cell 0-2 m; NK mixed layer scheme) | 100 km | NCAR-CLM4 | 250 km | none | Simple carbon aerosol model (emission type) | NCAR-CLM4 | TOPAZ2 | GFDL-SIS
LBLRTM-12-8 | AER | 2017 | RFMIP | Published | LBLRTM 12.8 | Line-By-Line Radiative Transfer Model v12.8, aer_v_3.6, MT_CKD_3.2 | none | none | none | none | none | none | none | none | none | none | none
MCM-UA-1-0 | UA | 1991 | CMIP FAFMIP PMIP ScenarioMIP | Published | MCM-UA-1-0 | Manabe Climate Model v1.0 - University of Arizona | R30L14 (3.75 X 2.5 degree (long-lat) configuration; 96 x 80 longitude/latitude; 14 levels; top level 0.015 sigma, 15 mb) | 250 km | MOM1.0 (MOM1, 1.875 X 2.5 deg; 192 x 80 longitude/latitude; 18 levels; top grid cell 0-40 m) | 250 km | Specified location - invariant in time, has high albedo and latent heat capacity | 250 km | Modifies surface albedoes (Haywood et al. 1997, doi: 10.1175/1520-0442(1997)010<1562:GCMCOT>2.0.CO;2) | none | Standard Manabe bucket hydrology scheme (Manabe 1969, doi: 10.1175/1520-0493(1969)097<0739:CATOC>2.3.CO;2) | none | Thermodynamic ice model (free drift dynamics)
MIROC-ES2H | MIROC | 2018 | AerChemMIP C4MIP CMIP DynVarMIP GeoMIP ScenarioMIP VIACSAB | Published | MIROC-ES2H | MIROC-ES2H | CCSR AGCM (T85; 256 x 128 longitude/latitude; 81 levels; top level 0.004 hPa) | 250 km | COCO4.9 (tripolar primarily 1deg; 360 x 256 longitude/latitude; 63 levels; top grid cell 0-2 m) | 100 km | none | none | SPRINTARS6.0 | CHASER4.0 (T42; 128 x 64 longitude/latitude; 81 levels; top level 0.004 hPa) | MATSIRO6.0+VISIT-e ver.1.0 | OECO ver.2.0; NPZD-type with C/N/P/Fe/O cycles | COCO4.9
MIROC-ES2H-NB | MIROC | 2019 | AerChemMIP CMIP | Published | MIROC-ES2H-NB | MIROC-ES2H with No BiogenicCycle | CCSR AGCM (T85; 256 x 128 longitude/latitude; 81 levels; top level 0.004 hPa) | 250 km | COCO4.9 (tripolar primarily 1deg; 360 x 256 longitude/latitude; 63 levels; top grid cell 0-2 m) | 100 km | none | none | SPRINTARS6.0 | CHASER4.0 (T42; 128 x 64 longitude/latitude; 81 levels; top level 0.004 hPa) | MATSIRO6 | none | COCO4.9
MIROC-ES2L | MIROC | 2018 | C4MIP CDRMIP CMIP DAMIP DynVarMIP GeoMIP LUMIP OMIP PMIP ScenarioMIP VIACSAB VolMIP | Published | MIROC-ES2L | MIROC-ES2L | CCSR AGCM (T42; 128 x 64 longitude/latitude; 40 levels; top level 3 hPa) | 500 km | COCO4.9 (tripolar primarily 1deg; 360 x 256 longitude/latitude; 63 levels; top grid cell 0-2 m) | 100 km | none | none | SPRINTARS6.0 | none | MATSIRO6.0+VISIT-e ver.1.0 | OECO ver.2.0; NPZD-type with C/N/P/Fe/O cycles | COCO4.9
MIROC6 | MIROC | 2017 | AerChemMIP CFMIP CMIP DAMIP DCPP DynVarMIP FAFMIP GMMIP HighResMIP LS3MIP OMIP PAMIP RFMIP SIMIP ScenarioMIP VIACSAB | Published | MIROC6 | MIROC6 | CCSR AGCM (T85; 256 x 128 longitude/latitude; 81 levels; top level 0.004 hPa) | 250 km | COCO4.9 (tripolar primarily 1deg; 360 x 256 longitude/latitude; 63 levels; top grid cell 0-2 m) | 100 km | none | none | SPRINTARS6.0 | none | MATSIRO6.0 | none | COCO4.9
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | 2017 | AerChemMIP CMIP RFMIP ScenarioMIP | Published | MPI-ESM1.2-HAM | MPI-ESM1.2-HAM | ECHAM6.3 (spectral T63; 192 x 96 longitude/latitude; 47 levels; top level 0.01 hPa) | 250 km | MPIOM1.63 (bipolar GR1.5, approximately 1.5deg; 256 x 220 longitude/latitude; 40 levels; top grid cell 0-12 m) | 250 km | none | none | HAM2.3 | sulfur chemistry (unnamed) | JSBACH 3.20 | HAMOCC6 | unnamed (thermodynamic (Semtner zero-layer) dynamic (Hibler 79) sea ice model)
MPI-ESM1-2-HR | MPI-M DWD DKRZ | 2017 | CMIP CORDEX DCPP DynVarMIP FAFMIP GeoMIP HighResMIP OMIP SIMIP ScenarioMIP VolMIP | Published | MPI-ESM1.2-HR | MPI-ESM1.2-HR | ECHAM6.3 (spectral T127; 384 x 192 longitude/latitude; 95 levels; top level 0.01 hPa) | 100 km | MPIOM1.63 (tripolar TP04, approximately 0.4deg; 802 x 404 longitude/latitude; 40 levels; top grid cell 0-12 m) | 50 km | none/prescribed | none | none, prescribed MACv2-SP | none | JSBACH3.20 | HAMOCC6 | unnamed (thermodynamic (Semtner zero-layer) dynamic (Hibler 79) sea ice model)
MPI-ESM1-2-LR | MPI-M AWI DKRZ DWD | 2017 | C4MIP CDRMIP CFMIP CMIP DAMIP DCPP DynVarMIP FAFMIP GMMIP GeoMIP ISMIP6 LS3MIP LUMIP OMIP PMIP RFMIP SIMIP ScenarioMIP VolMIP | Published | MPI-ESM1.2-LR | MPI-ESM1.2-LR | ECHAM6.3 (spectral T63; 192 x 96 longitude/latitude; 47 levels; top level 0.01 hPa) | 250 km | MPIOM1.63 (bipolar GR1.5, approximately 1.5deg; 256 x 220 longitude/latitude; 40 levels; top grid cell 0-12 m) | 250 km | none/prescribed | none | none, prescribed MACv2-SP | none | JSBACH3.20 | HAMOCC6 | unnamed (thermodynamic (Semtner zero-layer) dynamic (Hibler 79) sea ice model)
MPI-ESM1-2-XR | MPI-M | 2017 | HighResMIP | Published | MPI-ESM1.2-XR | MPI-ESM1.2-XR | ECHAM6.3 (spectral T255; 768 x 384 longitude/latitude; 95 levels; top level 0.01 hPa) | 50 km | MPIOM1.63 (tripolar TP04, approximately 0.4deg; 802 x 404 longitude/latitude; 40 levels; top grid cell 0-12 m) | 50 km | none/prescribed | none | none, prescribed MACv2-SP | none | JSBACH3.20 | HAMOCC6 | unnamed (thermodynamic (Semtner zero-layer) dynamic (Hibler 79) sea ice model)
MRI-AGCM3-2-H | MRI | 2017 | DynVarMIP HighResMIP | Published | MRI-AGCM3-2-H | MRI-AGCM3-2-H | MRI-AGCM3.2H (TL319; 640 x 320 longitude/latitude; 64 levels; top level 0.01 hPa) | 50 km | none | none | none | none | Prescribed from MRI-ESM2.0 | none | SIB0109 | none | none
MRI-AGCM3-2-S | MRI | 2017 | CMIP DynVarMIP HighResMIP | Published | MRI-AGCM3-2-S | MRI-AGCM3-2-S | MRI-AGCM3.2S (TL959; 1920 x 960 longitude/latitude; 64 levels; top level 0.01 hPa) | 25 km | none | none | none | none | Prescribed from MRI-ESM2.0 | none | SIB0109 | none | none
MRI-ESM2-0 | MRI | 2017 | AerChemMIP C4MIP CFMIP CMIP CORDEX DAMIP DCPP DynVarMIP FAFMIP GMMIP GeoMIP LS3MIP OMIP PMIP RFMIP SIMIP ScenarioMIP VolMIP | Published | MRI-ESM2.0 | MRI-ESM2.0 | MRI-AGCM3.5 (TL159; 320 x 160 longitude/latitude; 80 levels; top level 0.01 hPa) | 100 km | MRI.COM4.4 (tripolar primarily 0.5 deg latitude/1 deg longitude with meridional refinement down to 0.3 deg within 10 degrees north and south of the equator; 360 x 364 longitude/latitude; 61 levels; top grid cell 0-2 m) | 100 km | none | none | MASINGAR mk2r4 (TL95; 192 x 96 longitude/latitude; 80 levels; top level 0.01 hPa) | MRI-CCM2.1 (T42; 128 x 64 longitude/latitude; 80 levels; top level 0.01 hPa) | HAL 1.0 | MRI.COM4.4 | MRI.COM4.4
NESM3 | NUIST | 2016 | CMIP DAMIP DCPP GMMIP GeoMIP PMIP ScenarioMIP VolMIP | Published | NESM v3 | NUIST ESM v3 | ECHAM v6.3 (T63; 192 x 96 longitude/latitude; 47 levels; top level 1 Pa) | 250 km | NEMO v3.4 (NEMO v3.4, tripolar primarily 1deg; 384 x 362 longitude/latitude; 46 levels; top grid cell 0-6 m) | 100 km | none | none | none | none | JSBACH v3.1 | none | CICE4.1
NICAM16-7S | MIROC | 2017 | CMIP DynVarMIP HighResMIP | Published | NICAM16-7S | NICAM.16 gl07-L38 with NSW6 | NICAM.16 (56km icosahedral grid; 163,842 grid cells (=10*4^7+2); 38 levels; top level 40 km) | 100 km | none | none | none | none | Prescribed MACv2-SP | none | MATSIRO6 (w/o MOSAIC) | none | Fixed
NICAM16-8S | MIROC | 2017 | CMIP DynVarMIP HighResMIP | Published | NICAM16-8S | NICAM.16 gl08-L38 with NSW6 | NICAM.16 (28km icosahedral grid; 655,362 grid cells (=10*4^8+2); 38 levels; top level 40 km) | 50 km | none | none | none | none | Prescribed MACv2-SP | none | MATSIRO6 (w/o MOSAIC) | none | Fixed
NICAM16-9S | MIROC | 2017 | CMIP DynVarMIP HighResMIP | Published | NICAM16-9S | NICAM.16 gl09-L38 with NSW6 | NICAM.16 (14km icosahedral grid; 2,621,442 grid cells (=10*4^9+2); 38 levels; top level 40 km) | 25 km | none | none | none | none | Prescribed MACv2-SP | none | MATSIRO6 (w/o MOSAIC) | none | Fixed
NorCPM1 | NCC | 2019 | CMIP DCPP | Published | NorCPM1 | Norwegian Climate Prediction Model version 1 | CAM-OSLO4.1 (2 degree resolution; 144 x 96 longitude/latitude; 26 levels; top level ~2 hPa) | 250 km | MICOM1.1 (1 degree resolution; 320 x 384 longitude/latitude; 53 levels; top grid cell 0-2.5 m [native model uses hybrid density and generic upper-layer coordinate interpolated to z-level for contributed data]) | 100 km | none | none | OsloAero4.1 (same grid as atmos) | OsloChemSimp4.1 (same grid as atmos) | CLM4 (same grid as atmos) | HAMOCC5.1 (same grid as ocean) | CICE4 (same grid as ocean)
NorESM1-F | NCC | 2018 | CMIP PMIP | Published | NorESM1-F | NorESM1-F (a fast version of NorESM that is designed for paleo and multi-ensemble simulations) | CAM4 (2 degree resolution; 144 x 96; 32 levels; top level 3 mb) | 250 km | MICOM (1 degree resolution; 360 x 384; 70 levels; top grid cell minimum 0-2.5 m [native model uses hybrid density and generic upper-layer coordinate interpolated to z-level for contributed data]) | 100 km | CISM | 250 km | none | none | CLM4 | HAMOCC5.1 | CICE4
NorESM2-LM | NCC | 2017 | AerChemMIP C4MIP CDRMIP CFMIP CMIP DAMIP DCPP LUMIP OMIP PAMIP PMIP RFMIP ScenarioMIP VolMIP | Published | NorESM2-LM | NorESM2-LM (low atmosphere-medium ocean resolution, GHG concentration driven) | CAM-OSLO (2 degree resolution; 144 x 96; 32 levels; top level 3 mb) | 250 km | MICOM (1 degree resolution; 360 x 384; 70 levels; top grid cell minimum 0-2.5 m [native model uses hybrid density and generic upper-layer coordinate interpolated to z-level for contributed data]) | 100 km | CISM | 250 km | OsloAero | OsloChemSimp | CLM | HAMOCC | CICE
NorESM2-MM | NCC | 2017 | AerChemMIP CFMIP CMIP DAMIP OMIP RFMIP ScenarioMIP | Published | NorESM2-MM | NorESM2-MM (medium atmosphere-medium ocean resolution, GHG concentration driven) | CAM-OSLO (1 degree resolution; 288 x 192; 32 levels; top level 3 mb) | 100 km | MICOM (1 degree resolution; 360 x 384; 70 levels; top grid cell minimum 0-2.5 m [native model uses hybrid density and generic upper-layer coordinate interpolated to z-level for contributed data]) | 100 km | CISM | 100 km | OsloAero | OsloChemSimp | CLM | HAMOCC | CICE
PCMDI-test-1-0 | PCMDI | 1989 | CMIP | Registered | PCMDI-test 1.0 | PCMDI-test 1.0 (This entry is free text for users to contribute verbose information) | Earth1.0-gettingHotter (360 x 180 longitude/latitude; 50 levels; top level 0.1 mb) | 1x1 degree | BlueMarble1.0-warming (360 x 180 longitude/latitude; 50 levels; top grid cell 0-10 m) | 1x1 degree | none | none | none | none | Earth1.0 | none | Declining1.0-warming (360 x 180 longitude/latitude)
RRTMG-LW-4-91 | AER | 2017 | RFMIP | Published | RRTMG-LW 4.91 | RRTM for GCMs v4.91, longwave | none | none | none | none | none | none | none | none | none | none | none
RRTMG-SW-4-02 | AER | 2017 | RFMIP | Published | RRTMG-SW 4.02 | RRTM for GCMs v4.02, shortwave | none | none | none | none | none | none | none | none | none | none | none
RTE-RRTMGP-181204 | RTE-RRTMGP-Consortium | 2019 | RFMIP | Published | RTE+RRTMGP (2018-12-04 full-resolution) | Radiative Transfer for Energetics using RRTM for GCM applications - Parallel (2018-12-04 full-resolution) | none | none | none | none | none | none | none | none | none | none | none
SAM0-UNICON | SNU | 2017 | CMIP ScenarioMIP | Published | SAM0-UNICON | SAM0-UNICON (SNU Atmosphere Model version 0 with Unified Convection Scheme) | CAM5.3 with UNICON (1deg; 288 x 192 longitude/latitude; 30 levels; top level ~2 hPa) | 100 km | POP2 (Displaced Pole; 320 x 384 longitude/latitude; 60 levels; top grid cell 0-10 m) | 100 km | none | none | MAM3 | none | CLM4.0 | none | CICE4.0
TaiESM1 | AS-RCEC | 2018 | AerChemMIP CFMIP CMIP GMMIP LUMIP PAMIP PMIP RFMIP ScenarioMIP | Published | TaiESM 1.0 | Taiwan Earth System Model 1.0 | TaiAM1 (0.9x1.25 degree; 288 x 192 longitude/latitude; 30 levels; top level ~2 hPa) | 100 km | POP2 (320x384 longitude/latitude; 60 levels; top grid cell 0-10 m) | 100 km | none | none | SNAP (same grid as atmos) | SNAP (same grid as atmos) | CLM4.0 (same grid as atmos) | none | CICE4
TaiESM1-TIMCOM | NTU | 2020 | CMIP OMIP | Published | TaiESM1-TIMCOM | Taiwan Earth System Model 1.0 using TIMCOM ocean model | TaiAM1 (0.9x1.25 degree; 288 x 192 longitude/latitude; 30 levels; top level ~2 hPa) | 100 km | TIMCOM (TIMCOMv1.7, primarily 1deg; 360 x 288 longitude/latitude; 45 levels; top grid cell 0-10 m) | 100 km | none | none | SNAP (same grid as atmos) | SNAP (same grid as atmos) | CLM4.0 (same grid as atmos) | none | CICE4
TaiESM1-TIMCOM2 | NTU | 2021 | CMIP OMIP | Published | TaiESM1-TIMCOM2 | Taiwan Earth System Model 1.0 using TIMCOM ocean model 2.0 | TaiAM1 (0.9x1.25 degree; 288 x 192 longitude/latitude; 30 levels; top level ~2 hPa) | 100 km | TIMCOM (TIMCOMv2.2, primarily 1deg; 320 x 288 longitude/latitude; 55 levels; top grid cell 0-10 m) | 100 km | none | none | SNAP (same grid as atmos) | SNAP (same grid as atmos) | CLM4.0 (same grid as atmos) | none | CICE4 (same grid as ocean)
UKESM1-0-LL | MOHC NERC NIMS-KMA NIWA | 2018 | AerChemMIP C4MIP CDRMIP CMIP DAMIP GeoMIP LS3MIP LUMIP OMIP PMIP RFMIP ScenarioMIP VolMIP | Published | UKESM1.0-LL | UKESM1.0-N96ORCA1 | MetUM-HadGEM3-GA7.1 (N96; 192 x 144 longitude/latitude; 85 levels; top level 85 km) | 250 km | NEMO-HadGEM3-GO6.0 (eORCA1 tripolar primarily 1 deg with meridional refinement down to 1/3 degree in the tropics; 360 x 330 longitude/latitude; 75 levels; top grid cell 0-1 m) | 100 km | none | none | UKCA-GLOMAP-mode | UKCA-StratTrop | JULES-ES-1.0 | MEDUSA2 | CICE-HadGEM3-GSI8 (eORCA1 tripolar primarily 1 deg; 360 x 330 longitude/latitude)
UKESM1-1-LL | MOHC NERC NIMS-KMA NIWA | 2021 | CMIP ScenarioMIP | Published | UKESM1.1-LL | UKESM1.1-N96ORCA1 | MetUM-HadGEM3-GA7.1 (N96; 192 x 144 longitude/latitude; 85 levels; top level 85 km) | 250 km | NEMO-HadGEM3-GO6.0 (eORCA1 tripolar primarily 1 deg with meridional refinement down to 1/3 degree in the tropics; 360 x 330 longitude/latitude; 75 levels; top grid cell 0-1 m) | 100 km | none | none | UKCA-GLOMAP-mode | UKCA-StratTrop | JULES-ES-1.0 | MEDUSA2 | CICE-HadGEM3-GSI8 (eORCA1 tripolar primarily 1 deg; 360 x 330 longitude/latitude)
UKESM1-ice-LL | MOHC NERC | 2019 | ISMIP6 | Published | UKESM1.ice-LL | UKESM1.ice-N96ORCA1 | MetUM-HadGEM3-GA7.1 (N96; 192 x 144 longitude/latitude; 85 levels; top level 85 km) | 250 km | NEMO-HadGEM3-GO6.0 (eORCA1 tripolar primarily 1 deg with meridional refinement down to 1/3 degree in the tropics; 360 x 330 longitude/latitude; 75 levels; top grid cell 0-1 m) | 100 km | BISICLES-UKESM-ISMIP6-1.0 | 5 km | UKCA-GLOMAP-mode | none | JULES-ISMIP6-1.0 | none | CICE-HadGEM3-GSI8 (eORCA1 tripolar primarily 1 deg; 360 x 330 longitude/latitude)